@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ChangelogFromGit;
-BEGIN {
-  $Dist::Zilla::Plugin::ChangelogFromGit::VERSION = '0.003';
+{
+  $Dist::Zilla::Plugin::ChangelogFromGit::VERSION = '0.005';
 }
 
 # Indent style:
@@ -62,6 +62,7 @@ has releases => (
 		get_release   => 'get',
 		all_releases  => 'elements',
 	},
+	default => sub { [] },
 );
 
 has skipped_release_count => (
@@ -123,7 +124,7 @@ sub gather_files {
 		chomp( my $head_version = `git rev-list HEAD | tail -1` );
 		chomp( my $head_time    = `git show --format=%ct -n1 HEAD | head -1` );
 
-		if ($head_version ne $self->get_release(-1)->version()) {
+		if ( not $self->all_releases or $head_version ne $self->get_release(-1)->version()) {
 			$self->push_release(
 				Software::Release->new(
 					date    => DateTime->now(),
@@ -386,7 +387,7 @@ Dist::Zilla::Plugin::ChangelogFromGit - Write a Changes file from a project's gi
 
 =head1 VERSION
 
-version 0.003
+version 0.005
 
 =head1 SYNOPSIS
 
